pub fn render(input: &str) -> StringExpand description
Parse a ChordPro source string and render it to HTML.
Convenience wrapper that converts parse errors to a string.
Use try_render if you need error handling.
pub fn render(input: &str) -> StringParse a ChordPro source string and render it to HTML.
Convenience wrapper that converts parse errors to a string.
Use try_render if you need error handling.